package envoy.client;

import java.util.Properties;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>Config.java</strong><br>
 * Created: <strong>12 Oct 2019</strong><br>
 * 
 * @author Kai S. K. Engelbart
 * @since Envoy v0.1-alpha
 */
public class Config {

	private String	server;
	private int		port;

	/**
	 * Defaults to the {@code server.properties} file for information.
	 * 
	 * 
	 * @param properties - The two options for internet connection <strong>
	 *                   server</strong> and <strong> port</strong>
	 * @since Envoy v0.1-alpha
	 */
	public void load(Properties properties) {
		if (properties.containsKey("server")) server = properties.getProperty("server");
		if (properties.containsKey("port")) port = Integer.parseInt(properties.getProperty("port"));
	}

	/**
	 * Sets the server and the port via command line properties --server/ -s and
	 * --port/ -p.
	 * 
	 * @param args {@code --server} or {@code -s} followed by the specified URL
	 *             and {@code --port} or {@code -p} followed by a 4-digit Integer
	 * @since Envoy v0.1-alpha
	 */
	public void load(String[] args) {
		for (int i = 0; i < args.length; i++)
			switch (args[i]) {
				case "--server":
				case "-s":
					server = args[++i];
					break;
				case "--port":
				case "-p":
					port = Integer.parseInt(args[++i]);
					break;
			}
	}

	/**
	 * @return true if server and port are known.
	 * @since Envoy v0.1-alpha
	 */
	public boolean isInitialized() { return server != null && !server.isEmpty() && port > 0; }

	/**
	 * @return the URL of our website
	 * @since Envoy v0.1-alpha
	 */
	public String getServer() { return server; }

	/**
	 * Changes the default URL.
	 * Exclusively meant for developing reasons. (localhost)
	 * 
	 * @param server the URL where wish to host Envoy
	 * @since Envoy v0.1-alpha
	 */
	public void setServer(String server) { this.server = server; }

	/**
	 * @return the port at which Envoy is located in the Server
	 * @since Envoy v0.1-alpha
	 */
	public int getPort() { return port; }

	/**
	 * Changes the default port.
	 * Exclusively meant for developing reasons. (localhost)
	 * 
	 * @param port the port where we wish to connect to {@code Envoy}.
	 * @since Envoy v0.1-alpha
	 */
	public void setPort(int port) { this.port = port; }
}